@@ -46,7 +46,7 @@ $BASEDIR = $PICTURE_ROOT . "/" . $base;
 assert_path_ok($BASEDIR);
 $THUMB_ROOT = $PICTURE_ROOT;
 $BATCH = false;
-if ($argv[1] == "batch") {
+if (isset($argv) && $argv[1] == "batch") {
 	$BATCH = true;
 }
 
@@ -131,6 +131,7 @@ function get_description($path) {
 	$path .= "/";
 	$dirs = preg_split("/\//", $path);
 	$current = array_shift($dirs);
+	$description = array();
 	while (sizeof($dirs) > 0) {
 		if ( file_exists("$current/description.txt") ) {
 			$file = file("$current/description.txt");
@@ -238,7 +239,7 @@ function clean_tmp($dirname) {
 /****************************************************************************/
 
 /****************************************************************************/
-/* Resize an image, returns temp file name, depends on php5-imagick */
+/* Resize an image, returns temp file name, depends on php-imagick */
 function do_resize_picture($path_to_picture, $width, $height, $rotate) {
 	$path_parts = preg_split("/\//", $path_to_picture);
 	$file = array_pop($path_parts);
